@@ -44,7 +44,7 @@ class Description(Node):
                     continue
                 if lang not in lang_part_counts:
                     lang_part_counts[lang] = 0
-                self.object[lang] += f'<p>{html.escape(n.text.strip(), quote=False)}</p>\n'
+                self.object[lang] += f'<p>{html.escape(n.text, quote=False)}</p>\n'
                 lang_part_counts[lang] += 1
             elif n.tag in ['ol', 'ul']:
                 langs = set()
@@ -58,7 +58,7 @@ class Description(Node):
                         langs.add(lang)
                         if not (self.object[lang].endswith('</li>\n') or self.object[lang].endswith(f'<{n.tag}>\n')):
                             self.object[lang] += f'<{n.tag}>\n'
-                        self.object[lang] += f'  <li>{html.escape(c.text.strip(), quote=False)}</li>\n'
+                        self.object[lang] += f'  <li>{html.escape(c.text, quote=False)}</li>\n'
                         lang_part_counts[lang] += 1
                     else:
                         raise AppStreamParseError(f'Expected <li> in <{n.tag}>, got <{c.tag}>')
@@ -241,7 +241,11 @@ class Provide(Node):
             if c2.tag in self.TYPES:
                 attr = self.TYPES[c2.tag]
                 current = getattr(self, attr)
-                current.append(c2.text.strip())
+                if c2.tag == 'dbus':
+                    if 'type' in c2.attrib and c2.get('type') in ['user', 'system']:
+                        current.append({'type': c2.get('type'), 'service': c2.text.strip()})
+                else:
+                    current.append(c2.text.strip())
                 setattr(self, attr, current)
 
 
